@@ -39,7 +39,12 @@ extern zend_module_entry yaf_module_entry;
 #define YAF_G(v) (yaf_globals.v)
 #endif
 
-#define PHP_YAF_VERSION 					"3.0.7"
+#ifndef ZEND_ACC_CTOR
+# define ZEND_ACC_CTOR	0x0
+# define ZEND_ACC_DTOR	0x0
+#endif
+
+#define PHP_YAF_VERSION 					"3.0.8"
 
 #define YAF_STARTUP_FUNCTION(module)   	ZEND_MINIT_FUNCTION(yaf_##module)
 #define YAF_RINIT_FUNCTION(module)		ZEND_RINIT_FUNCTION(yaf_##module)
